
from ZCVSMixin import ZCVSMixin, do_break
from Globals import HTMLFile, MessageDialog
import OFS

class CVSFolder(ZCVSMixin, OFS.SimpleItem.Item):
    id = 'CVS'
    meta_type = 'CVS Folder'
    
    def _containerObjectIds(self):
        return filter(lambda id: id != 'CVS', self.aq_parent.objectIds())

    def _containerHasID(self, id):
        """ Check to see if container has this ID """
        if self.isInZClass:
            parent = self.aq_parent
            return parent.getClassAttr(id, parent) is not parent
        else:
            return id in self._containerObjectIds()

    def _container_p_jar(self):
        return self.aq_parent._p_jar

    def _containerDelObject(self, id):
        if id != 'CVS':  # For sanity
            self.aq_parent._delObject(id)

    def _containerSetObject(self, id, value):
        if id != 'CVS':  # For sanity
            self.aq_parent._setObject(id, value)

    def _containerGetattr(self, id):
        if id != 'CVS':  # For sanity
            if self.isInZClass:
                attr = self.aq_parent[id]
            else:
                attr = getattr(self.aq_parent, id)
            return attr
        else:
            raise AttributeError, id
    
    def _setId(self, id):
        if id != self.id:
            raise MessageDialog(
                title='Invalid Id',
                message='Cannot change the id of a CVSFolder',
                action ='./manage_main',)

    def __init__(self, fsroot, fsrepos, addfsdir, usepassfile, passfile, default_gargs, isInZClass=0):
        self.fsroot = fsroot
        self.fsrepos = fsrepos
        self.addfsdir = addfsdir
        self.usepassfile = usepassfile
        self.passfile=passfile
        self.default_gargs = default_gargs
        self.isInZClass = isInZClass

manage_addCVSFolderForm = HTMLFile('addCVSFolder', globals())

def manage_addCVSFolder(self, fsroot, fsrepos, addfsdir=0, usepassfile=0, passfile='',
                        default_gargs='', isInZClass=0, REQUEST=None):
    '''Adds a CVS folder to the current folder.
    '''

    # do_break()
    ob = CVSFolder(fsroot, fsrepos, addfsdir, usepassfile, passfile, default_gargs, isInZClass)

    if addfsdir:
        ob.active = 1
        result = ob.manage_addfsdirCVS(default_gargs)
    else:
        result = 'no new directory added'

    if isInZClass:
        ob.id = ob.id + '_ZClass'

    self._setObject(ob.id, ob)

    return MessageDialog(title='OK',
                         message = ' Added CVS Folder.. <pre> add result: ' + result + '</pre>',
                         action='manage_main')

